@@ -1,5 +1,6 @@
 from .engines import mysqlDefault
 from .engines import mysqlDocker
+from .engines import mongoDocker
 
 # Entry Function
 
@@ -12,6 +13,8 @@ def start(config):
         MsqModule = mysqlDefault
     elif (DB_ENGINE == 'mysqlDocker'):
         MsqModule = mysqlDocker
+    elif (DB_ENGINE == 'mongoDocker'):
+        MsqModule = mongoDocker
     else:
         MsqModule = mysqlDefault
 
